==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-directorymenu/translations/directorymenu_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="125"/>
        <source>Open</source>
        <translation>Öppna</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="129"/>
        <source>Open in terminal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Inställningar för mapp-meny</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Basmapp:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>BaseDirectoryName</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="73"/>
        <location filename="../directorymenuconfiguration.cpp" line="112"/>
        <source>Choose Default Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="96"/>
        <source>Choose Base Directory</source>
        <translation>Välj basmapp</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="126"/>
        <source>Choose Icon</source>
        <translation>Välj ikon</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="126"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Ikoner (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="135"/>
        <source>Directory Menu</source>
        <translation>Mapp-meny</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="135"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Ett fel inträffade när ikonen laddades.</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.17.1.orig.tar.xz: lxqt-panel-0.17.1/plugin-directorymenu/translations/directorymenu_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="125"/>
        <source>Open</source>
        <translation>Öppna</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="129"/>
        <source>Open in terminal</source>
        <translation>Öppna i terminal</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Inställningar för mapp-meny</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Basmapp:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>BaseDirectoryName</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="73"/>
        <location filename="../directorymenuconfiguration.cpp" line="112"/>
        <source>Choose Default Terminal</source>
        <translation>Välj standard Terminal</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="96"/>
        <source>Choose Base Directory</source>
        <translation>Välj basmapp</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="126"/>
        <source>Choose Icon</source>
        <translation>Välj ikon</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="126"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Ikoner (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="135"/>
        <source>Directory Menu</source>
        <translation>Mapp-meny</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="135"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Ett fel inträffade när ikonen laddades.</translation>
    </message>
</context>
</TS>
